<!--- 
	csw-herocarousel-generic-rh.cfm

	This 'generic' render handler implements the 'getGenericFieldMappingsArray' function below to describe
	the available field that can be mapped.

	The logic above the function, renders an image with a caption above it, and optionally a description textblock, 
	and/or link/button.
	
	Note that for 'generic' render handlers the mapped data, if any, will always be passed in the following structure:
		Attributes.ElementInfo.ElementData.PropertyValues
	This is an array of one or more items, with a sub-structure named 'values'.
	Values is a structure with members as defined by the getGenericFieldMappingsArray() function.

	This generic render handler assumes these fields for each slide:
		- Title - Required 
		- Image - Required
		- Description - Optional - defaults to empty string
		- DescriptionStyle - Optional
		- LinkURL - Optional - defaults to empty string
		- LinkText - Optional - defaults to empty string
		- TitleTag - Optional - defaults to 'div'
		- TitlePosition - Optional - defaults to 'cswTextAlignCenter'
		- TitleStyle - Optional - defaults to 'cswTitleBlue'
		- DescriptionPosition - Optional - defaults to 'cswTextAlignCenter'
		- ButtonPosition - Optional - defaults to 'cswTextAlignBottomRight'
		- ButtonStyle - Optional - defaults to 'btn'
		- ButtonSize - Optional - defaults to empty string
		- ImagePosition - Optional - defaults to 'center center'
		
	Additionally this generic render handler assumes it is bound to a MetaData Form the has these fields:
		- Options: A comma delimmited list of these possible values:
				showdots 
				showarrows
				draggable 
				showthumbs 
				infiniteloop
				fixedheight
				autoheight
		- slideWaitTime - defaults to 3000
		- slideTransitionSpeed - defaults to 1000
		- SlideTransitionEffect - defaults to 'slide', possible values are:
				slide
				fade
				cube
				coverflow
				flip
	
	Version: [2018-01-17 9:40]
--->

<cfscript>
	// Create the HeroCarousel Component
	cswHeroCarousel = CreateObject('component','_cs_widgets.csw-herocarousel.renderhandlers.csw-herocarousel');
	
	// load necessary resources
	cswHeroCarousel.loadResources();
	
		// exit if all we're doing is detecting required resources
	if ( Request.RenderState.RenderMode EQ "getResources" )
		exit;

	if ( NOT structKeyExists(attributes,'elementinfo') )
		exit;
		
	// Load the Properties from the metadata form		
	props = cswHeroCarousel.loadProperties(Attributes.ElementInfo,Variables.Caller);	
	
	// Make sure we have Props data
	if( NOT cswHeroCarousel.hasProperties(props) )
		exit;
		
	// Get the element Data and Render the items
	if( StructKeyExists(Attributes.ElementInfo.ElementData, 'PropertyValues') )
		cswHeroCarousel.getAndRenderItems( Attributes.ElementInfo.ElementData, props, request.element.id );
	
</cfscript>

<!--- ////////////////////////////////////////////////////////////////////////// --->
<!--- //////////////////   GENERIC RENDER HANDLER FUNCTIONS   ////////////////// --->
<!--- ////////////////////////////////////////////////////////////////////////// --->

<!---
	This is the function that is called by CommonSpot when this render handler is registred, allowing the user to
	map the fields of the source element to this render handler.

	Here we expose build a structure describing the fields that can be mapped, and whether they are required or not

	Each fieldMappingArray item is a structure with the following 3 fields:
		- FieldName
		- Description
		- Required
--->
<cffunction name="getGenericFieldMappingsArray" returntype="array" access="private" output="no">
	<cfscript>
		var fieldMappingArray = ArrayNew(1);
		var fieldDetailsStruct = StructNew();
		
		// Slide & Image Properties
		// ----------------------
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'SlideBackgroundColor';
		fieldDetailsStruct.Description = 'The background color of the slide.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Image';
		fieldDetailsStruct.Description = 'The server relative URL to the image to display in the slide.';
		fieldDetailsStruct.Required = 1;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'ImagePosition';
		fieldDetailsStruct.Description = "The string that is set as the value of the background-position style, controlling the focal point of the image. For example, 'top left', or 'bottom right'. Defaults to 'center center'.";
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);
		
		
		// Title Properties
		// -----------------------

		// Title Position
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'TitlePosition';
		fieldDetailsStruct.Description = 'The CSS class that controls where the title will appear on the slide.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);
		
		// Title
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Title';
		fieldDetailsStruct.Description = 'The title text to display in the slide.';
		fieldDetailsStruct.Required = 1;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);
		
		// Title Style
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'TitleStyle';
		fieldDetailsStruct.Description = 'JSON string that describes the appearance of the title';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);		
		
		
		// Description Properties
		// -----------------------

		// Description Position		
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'DescriptionPosition';
		fieldDetailsStruct.Description = 'The CSS class that controls where the description text will appear on the slide.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);		
		
		// Description
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Description';
		fieldDetailsStruct.Description = 'The description text to display in the slide.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);
		
		// Description Style
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'DescriptionStyle';
		fieldDetailsStruct.Description = 'JSON string that describes the appearance of the description';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);		
		
		
		
		// Link/Button Properties
		// -----------------------
		
		// Link URL
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'LinkURL';
		fieldDetailsStruct.Description = 'The server relative URL visitors will be navigated to when clicking any of the links on the slide';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);
		
		// Button Position
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'ButtonPosition';
		fieldDetailsStruct.Description = 'The CSS class that controls where the link/button will appear on the slide.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);
		
		// Link Text
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'LinkText';
		fieldDetailsStruct.Description = 'The text that will render for the Link or Button in the slide.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);
		
		// Button Type
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'ButtonType';
		fieldDetailsStruct.Description = 'The CSS class that specifies how to render the link/button.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);
		
		// Button Appearance
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'ButtonStyle';
		fieldDetailsStruct.Description = 'JSON string that controls the style of the link/button.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);		
		
		// Button Corners
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'ButtonCorner';
		fieldDetailsStruct.Description = 'The CSS class that controls the style of the button corners.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);			
		
		// Link Appearance
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'LinkStyle';
		fieldDetailsStruct.Description = 'JSON string that controls the style of the link';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);		
		
		// Link/Button Icon
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'ButtonIcon';
		fieldDetailsStruct.Description = 'The CSS class used to render the link/button icon.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);			

		return fieldMappingArray;
	</cfscript>
</cffunction>
		

